@@ -1,13 +1,13 @@
+# Copyright 2021 UW-IT, University of Washington
+# SPDX-License-Identifier: Apache-2.0
+
 """
 Interfacing with the IASytem API, Evaluation resource.
 """
-import pytz
 import logging
 import re
-try:
-    from urllib import urlencode
-except ImportError:
-    from urllib.parse import urlencode
+from dateutil.parser import parse
+from urllib.parse import urlencode
 from uw_iasystem import get_resource
 from uw_iasystem.models import Evaluation
 from datetime import datetime
@@ -31,7 +31,7 @@ def search_evaluations(domain, **kwargs):
     returns:
       a list of Evaluation objects
     """
-    url = "%s?%s" % (IAS_PREFIX, urlencode(kwargs))
+    url = "{}?{}".format(IAS_PREFIX, urlencode(kwargs))
     data = get_resource(url, domain)
     evaluations = _json_to_evaluation(data)
 
@@ -39,7 +39,7 @@ def search_evaluations(domain, **kwargs):
 
 
 def get_evaluation_by_id(evaluation_id, domain):
-    url = "%s/%s" % (IAS_PREFIX, evaluation_id)
+    url = "{}/{}".format(IAS_PREFIX, evaluation_id)
     return _json_to_evaluation(get_resource(url, domain))
 
 
@@ -186,17 +186,7 @@ def get_response_rate(data):
     return float(str(response_rate) if response_rate else '0')
 
 
-def get_is_online(data):
-    if get_value_by_name(data, 'deliveryMethod') == "Online":
-        return True
-    return False
-
-
 def _datetime_from_string(date_string):
-    if date_string:
-        date_format = "%Y-%m-%dT%H:%M:%S"
-        date_string = date_string.replace("Z", "")
-        date = datetime.strptime(date_string, date_format)
-        return pytz.utc.localize(date)
-
+    if date_string is not None and len(date_string):
+        return parse(date_string)
     return ""
