@@ -1,6 +1,10 @@
+# Copyright 2021 UW-IT, University of Washington
+# SPDX-License-Identifier: Apache-2.0
+
 from unittest import TestCase
-from uw_iasystem.dao import IASystem_DAO, IASystem_UW_DAO, IASystem_UWB_DAO,\
-    IASystem_UWT_DAO, IASystem_UWEO_AP_DAO, IASystem_UWEO_IELP_DAO
+from uw_iasystem.dao import (
+    IASystem_DAO, IASystem_UW_DAO, IASystem_UWB_DAO, IASystem_UWT_DAO,
+    IASystem_UWEO_AP_DAO, IASystem_UWEO_IELP_DAO)
 
 
 class IASystemDaoTest(TestCase):
@@ -9,16 +13,16 @@ class IASystemDaoTest(TestCase):
         self.assertRaises(Exception, IASystem_DAO, None)
         self.assertEqual(len(IASystem_DAO("Seattle")), 1)
         self.assertTrue(isinstance(IASystem_DAO("Seattle")[0],
-                                   IASystem_UW_DAO))
+                        IASystem_UW_DAO))
         self.assertTrue(isinstance(IASystem_DAO("Bothell")[0],
-                                    IASystem_UWB_DAO))
+                        IASystem_UWB_DAO))
         self.assertTrue(isinstance(IASystem_DAO("Tacoma")[0],
-                                    IASystem_UWT_DAO))
+                        IASystem_UWT_DAO))
         self.assertEqual(len(IASystem_DAO("PCE_AP")), 1)
         self.assertTrue(isinstance(IASystem_DAO("PCE_AP")[0],
-                                    IASystem_UWEO_AP_DAO))
+                        IASystem_UWEO_AP_DAO))
         self.assertTrue(isinstance(IASystem_DAO("PCE_OL")[0],
-                                    IASystem_UWEO_AP_DAO))
+                        IASystem_UWEO_AP_DAO))
         self.assertTrue(isinstance(IASystem_DAO("PCE_IELP")[0],
-                                    IASystem_UWEO_IELP_DAO))
+                        IASystem_UWEO_IELP_DAO))
         self.assertEqual(len(IASystem_DAO("pce")), 2)
