@@ -1,16 +1,17 @@
+# Copyright 2021 UW-IT, University of Washington
+# SPDX-License-Identifier: Apache-2.0
+
 import datetime
 import pytz
 from unittest import TestCase
 from restclients_core.exceptions import DataFailureException
 from uw_iasystem.exceptions import TermEvalNotCreated
-from uw_iasystem.evaluation import search_evaluations,\
-    get_evaluation_by_id, get_domain
+from uw_iasystem.evaluation import (
+    search_evaluations, get_evaluation_by_id, get_domain)
 from uw_iasystem.tests import fdao_ias_override
-from uw_pws.util import fdao_pws_override
 
 
 @fdao_ias_override
-@fdao_pws_override
 class IASystemTest(TestCase):
 
     def test_get_domain(self):
@@ -59,12 +60,12 @@ class IASystemTest(TestCase):
         self.assertFalse(evals[1].is_completed)
 
         evals1 = search_evaluations("Seattle",
-                                   year=2013,
-                                   term_name='Spring',
-                                   curriculum_abbreviation='TRAIN',
-                                   course_number=100,
-                                   section_id='A',
-                                   student_id=1033334)
+                                    year=2013,
+                                    term_name='Spring',
+                                    curriculum_abbreviation='TRAIN',
+                                    course_number=100,
+                                    section_id='A',
+                                    student_id=1033334)
         self.assertTrue(evals1[1].is_pending())
 
     def test_search_report(self):
@@ -215,17 +216,17 @@ class IASystemTest(TestCase):
 
     def test_pce_evals_by_instructor(self):
         pce_evals = search_evaluations("pce",
-                                   year=2013,
-                                   term_name='Summer',
-                                   instructor_id=123456789)
+                                       year=2013,
+                                       term_name='Summer',
+                                       instructor_id=123456789)
         self.assertIsNotNone(pce_evals)
         self.assertEqual(pce_evals[0].section_sln, 165165)
         self.assertTrue(pce_evals[0].is_eo_ap())
 
         ap_evals = search_evaluations("pce_ap",
-                                   year=2013,
-                                   term_name='Summer',
-                                   instructor_id=123456789)
+                                      year=2013,
+                                      term_name='Summer',
+                                      instructor_id=123456789)
         self.assertIsNotNone(ap_evals)
         eval0 = ap_evals[0]
         self.assertEqual(eval0.section_sln, 165165)
@@ -246,9 +247,9 @@ class IASystemTest(TestCase):
         self.assertIsNone(eval0.report_url)
 
         ap_evals = search_evaluations("PCE_OL",
-                                   year=2013,
-                                   term_name='Summer',
-                                   instructor_id=123456789)
+                                      year=2013,
+                                      term_name='Summer',
+                                      instructor_id=123456789)
         self.assertIsNotNone(ap_evals)
         self.assertEqual(ap_evals[0].section_sln, 165165)
         self.assertTrue(ap_evals[0].is_eo_ap())
@@ -257,12 +258,12 @@ class IASystemTest(TestCase):
         self.assertTrue(data['is_eo_ap'])
 
         ielp_evals = search_evaluations("PCE_IELP",
-                                   year=2013,
-                                   term_name='Summer',
-                                   curriculum_abbreviation='CSOC',
-                                   course_number=100,
-                                   section_id='A',
-                                   instructor_id=123456789)
+                                        year=2013,
+                                        term_name='Summer',
+                                        curriculum_abbreviation='CSOC',
+                                        course_number=100,
+                                        section_id='A',
+                                        instructor_id=123456789)
         self.assertIsNotNone(ielp_evals)
         self.assertIsNotNone(str(ielp_evals[0]))
         self.assertEqual(ielp_evals[0].section_sln, 168569)
@@ -273,12 +274,12 @@ class IASystemTest(TestCase):
         self.assertTrue(data['is_eo_ielp'])
 
         pce_evals = search_evaluations("pce",
-                                   year=2013,
-                                   term_name='Summer',
-                                   curriculum_abbreviation='CSOC',
-                                   course_number=100,
-                                   section_id='A',
-                                   instructor_id=123456789)
+                                       year=2013,
+                                       term_name='Summer',
+                                       curriculum_abbreviation='CSOC',
+                                       course_number=100,
+                                       section_id='A',
+                                       instructor_id=123456789)
         self.assertIsNotNone(pce_evals)
         self.assertIsNotNone(str(pce_evals[0]))
         self.assertEqual(pce_evals[0].section_sln, 168569)
